@@ -14,8 +14,9 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __LIBGCMD_H__
 #define __LIBGCMD_H__
 
@@ -30,4 +31,7 @@
 #include <libgcmd/gnome-cmd-string-dialog.h>
 #include <libgcmd/plugin-info.h>
 
+G_BEGIN_DECLS
+G_END_DECLS
+
 #endif //__LIBGCMD_H__
