@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -25,8 +25,9 @@
 #include "file-roller-small.xpm"
 
 #define NAME "File Roller"
-#define COPYRIGHT "Copyright 2003 Marcus Bjurman"
+#define COPYRIGHT "Copyright \xc2\xa9 2003-2006 Marcus Bjurman"
 #define AUTHOR "Marcus Bjurman <marbj499@student.liu.se>"
+#define WEBPAGE "http://www.nongnu.org/gcmd"
 
 
 static PluginInfo plugin_nfo = {
@@ -38,19 +39,41 @@ static PluginInfo plugin_nfo = {
     NULL,
     NULL,
     NULL,
-    NULL
+    WEBPAGE
 };
 
+
 static gchar *handled_extensions[] =
 {
-    ".tar.bz2",
-    ".tar.gz",
-    ".tar.Z",
-    ".zip",
-    ".tgz",
+    ".7z",          // 7-zip
+    ".ar",          // ar
+    ".arj",         // arj
+    ".bin",         // stuffit
+    ".deb",         // Debian archives
+    ".ear",         // jar
+    ".jar",         // jar
+    ".lzh",         // lha
+    ".rar",         // rar
+    ".rpm",         // RPM archives
+    ".sit",         // stuffit
+    ".tar",         // tar
+    ".tar.Z",       // tar+compress
+    ".tar.bz",      // tar+bz
+    ".tar.bz2",     // tar+bz2
+    ".tar.gz",      // tar+gz
+    ".tar.lzo",     // tar+lzop
+    ".taz",         // tar+compress
+    ".tbz",         // tar+bz
+    ".tbz2",        // tar+bz2
+    ".tgz",         // tar+gz
+    ".tzo",         // tar+lzop
+    ".war",         // jar
+    ".zip",         // zip
+    ".zoo",         // zoo
     NULL
 };
 
+
 struct _FileRollerPluginPrivate
 {
     GtkWidget *conf_dialog;
@@ -67,22 +90,16 @@ static GnomeCmdPluginClass *parent_class = NULL;
 static void
 on_extract_cwd (GtkMenuItem *item, GnomeVFSURI *uri)
 {
-    gchar *uri_str;
-    gchar *target_arg, *archive_arg, *target_name, *target_dir, *local_path;
+    gchar *target_arg, *archive_arg, *target_dir;
+    gchar *uri_str = gnome_vfs_uri_to_string (uri, 0);
+    gchar *local_path = gnome_vfs_get_local_path_from_uri (uri_str);
+    gchar *target_name = gtk_object_get_data (GTK_OBJECT (item), "target_name");
     gchar *cmd, *t;
 
-    uri_str = gnome_vfs_uri_to_string (uri, 0);
-    local_path = gnome_vfs_get_local_path_from_uri (uri_str);
-    target_name = gtk_object_get_data (GTK_OBJECT (item), "target_name");
-
-    t = g_dirname (local_path);
-     if (target_name) {
-        target_dir = g_build_path ("/", t, target_name, NULL);
-        g_free (target_name);
-    }
-    else
-        target_dir = g_strdup (t);
+    t = g_path_get_dirname (local_path);
+    target_dir = target_name ? g_build_path (G_DIR_SEPARATOR_S, t, target_name, NULL) : g_strdup (t);
     g_free (t);
+    g_free (target_name);
 
     t = g_strdup_printf ("--extract-to=%s", target_dir);
     target_arg = g_shell_quote (t);
@@ -91,7 +108,7 @@ on_extract_cwd (GtkMenuItem *item, GnomeVFSURI *uri)
     archive_arg = g_shell_quote (local_path);
     cmd = g_strdup_printf ("file-roller %s %s", target_arg, archive_arg);
 
-    t = g_dirname (local_path);
+    t = g_path_get_dirname (local_path);
     gnome_execute_shell (t, cmd);
     g_free (t);
 
@@ -113,9 +130,8 @@ do_add_to_archive (const gchar *name, GnomeCmdState *state)
     gchar *active_dir_path, *uri_str;
     GList *files;
 
-    files = state->active_dir_selected_files;
-
-    while (files) {
+    for (files = state->active_dir_selected_files; files; files = files->next)
+    {
         GnomeVFSURI *uri = GNOME_CMD_FILE_INFO (files->data)->uri;
         gchar *uri_str = gnome_vfs_uri_to_string (uri, 0);
         gchar *path = gnome_vfs_get_local_path_from_uri (uri_str);
@@ -126,7 +142,6 @@ do_add_to_archive (const gchar *name, GnomeCmdState *state)
         g_free (path);
         g_free (tmp);
         g_free (uri_str);
-        files = files->next;
     }
 
     g_printerr ("add: %s\n", cmd);
@@ -155,7 +170,8 @@ on_add_to_archive (GtkMenuItem *item, FileRollerPlugin *plugin)
 
     files = plugin->priv->state->active_dir_selected_files;
 
-    do {
+    do
+    {
         if (dialog)
             gtk_widget_destroy (dialog);
 
@@ -195,7 +211,8 @@ on_add_to_archive (GtkMenuItem *item, FileRollerPlugin *plugin)
         name = gtk_entry_get_text (GTK_ENTRY (entry));
         if (name != NULL && strlen (name) > 0)
             name_ok = TRUE;
-    } while (name_ok == FALSE && ret == GTK_RESPONSE_OK);
+    }
+    while (name_ok == FALSE && ret == GTK_RESPONSE_OK);
 
     if (ret == GTK_RESPONSE_OK)
         do_add_to_archive (name, plugin->priv->state);
@@ -214,10 +231,10 @@ create_menu_item (const gchar *name, gboolean show_pixmap,
     if (show_pixmap) {
         item = gtk_image_menu_item_new ();
         pixmap = gnome_pixmap_new_from_xpm_d ((const gchar**)file_roller_small_xpm);
-        if (pixmap) {
+        if (pixmap)
+        {
             gtk_widget_show (pixmap);
-            gtk_image_menu_item_set_image (
-                GTK_IMAGE_MENU_ITEM (item), pixmap);
+            gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), pixmap);
         }
     }
     else
@@ -232,9 +249,7 @@ create_menu_item (const gchar *name, gboolean show_pixmap,
     gtk_container_add (GTK_CONTAINER (item), label);
 
     /* Connect to the signal and set user data */
-    gtk_object_set_data (GTK_OBJECT (item),
-                         GNOMEUIINFO_KEY_UIDATA,
-                         data);
+    gtk_object_set_data (GTK_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, data);
 
     if (callback)
         gtk_signal_connect (GTK_OBJECT (item), "activate", callback, data);
@@ -269,35 +284,30 @@ create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *state)
 
     FILE_ROLLER_PLUGIN (plugin)->priv->state = state;
 
-    item = create_menu_item (
-        _("Create Archive..."),
+    item = create_menu_item (_("Create Archive..."),
         TRUE, GTK_SIGNAL_FUNC (on_add_to_archive), plugin);
     items = g_list_append (items, item);
 
-    if (num_files == 1) {
-        gint i=0;
+    if (num_files == 1)
+    {
         GnomeCmdFileInfo *finfo = GNOME_CMD_FILE_INFO (files->data);
         gchar *fname = g_strdup (finfo->info->name);
+        gint i;
 
-        while (handled_extensions[i] != NULL) {
-            if (g_str_has_suffix (fname, handled_extensions[i])) {
-                gchar *text;
+        for (i=0; handled_extensions[i] != NULL && ! (fname, handled_extensions[i]); ++i)
+        {
+            gchar *text;
 
-                item = create_menu_item (
-                    _("Extract in Current Directory"),
-                    TRUE, GTK_SIGNAL_FUNC (on_extract_cwd), finfo->uri);
-                items = g_list_append (items, item);
+            item = create_menu_item (_("Extract in Current Directory"),
+                TRUE, GTK_SIGNAL_FUNC (on_extract_cwd), finfo->uri);
+            items = g_list_append (items, item);
 
-                fname[strlen(fname)-strlen(handled_extensions[i])] = '\0';
-                text = g_strdup_printf (_("Extract to '%s'"), fname);
-                item = create_menu_item (
-                    text, TRUE, GTK_SIGNAL_FUNC (on_extract_cwd), finfo->uri);
-                gtk_object_set_data (GTK_OBJECT (item), "target_name", g_strdup (fname));
-                items = g_list_append (items, item);
-                g_free (text);
-                break;
-            }
-            i++;
+            fname[strlen(fname)-strlen(handled_extensions[i])] = '\0';
+            text = g_strdup_printf (_("Extract to '%s'"), fname);
+            item = create_menu_item (text, TRUE, GTK_SIGNAL_FUNC (on_extract_cwd), finfo->uri);
+            gtk_object_set_data (GTK_OBJECT (item), "target_name", g_strdup (fname));
+            items = g_list_append (items, item);
+            g_free (text);
         }
         g_free (fname);
     }
@@ -318,9 +328,7 @@ on_configure_close (GtkButton *btn, FileRollerPlugin *plugin)
     plugin->priv->default_ext = g_strdup (gtk_entry_get_text (
         GTK_ENTRY (GTK_COMBO (plugin->priv->conf_combo)->entry)));
 
-    gnome_cmd_data_set_string (
-        "/file-runner-plugin/default_type",
-        plugin->priv->default_ext);
+    gnome_cmd_data_set_string ("/file-runner-plugin/default_type", plugin->priv->default_ext);
 
     gtk_widget_hide (plugin->priv->conf_dialog);
 }
@@ -337,15 +345,13 @@ configure (GnomeCmdPlugin *plugin)
     gnome_cmd_dialog_set_transient_for (
         GNOME_CMD_DIALOG (dialog),
         GTK_WINDOW (main_win_widget));
-    gnome_cmd_dialog_set_modal (
-        GNOME_CMD_DIALOG (dialog));
+    gnome_cmd_dialog_set_modal (GNOME_CMD_DIALOG (dialog));
 
     gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_OK,
                                  GTK_SIGNAL_FUNC (on_configure_close), plugin);
 
     vbox = create_vbox (dialog, FALSE, 12);
-    gnome_cmd_dialog_add_expanding_category (
-        GNOME_CMD_DIALOG (dialog), vbox);
+    gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), vbox);
 
 
     table = create_table (dialog, 2, 2);
@@ -358,7 +364,7 @@ configure (GnomeCmdPlugin *plugin)
     combo = create_combo (dialog);
     table_add (table, combo, 1, 1, GTK_FILL);
 
-    for ( i=0 ; handled_extensions[i] != NULL ; i++ )
+    for (i=0 ; handled_extensions[i] != NULL ; i++)
         items = g_list_append (items, handled_extensions[i]);
 
     gtk_combo_set_popdown_strings (GTK_COMBO (combo), items);
@@ -373,7 +379,6 @@ configure (GnomeCmdPlugin *plugin)
 }
 
 
-
 /*******************************
  * Gtk class implementation
  *******************************/
@@ -394,11 +399,9 @@ destroy (GtkObject *object)
 static void
 class_init (FileRollerPluginClass *klass)
 {
-    GtkObjectClass *object_class;
-    GnomeCmdPluginClass *plugin_class;
+    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+    GnomeCmdPluginClass *plugin_class = GNOME_CMD_PLUGIN_CLASS (klass);
 
-    object_class = GTK_OBJECT_CLASS (klass);
-    plugin_class = GNOME_CMD_PLUGIN_CLASS (klass);
     parent_class = gtk_type_class (gnome_cmd_plugin_get_type ());
 
     object_class->destroy = destroy;
@@ -415,12 +418,10 @@ init (FileRollerPlugin *plugin)
 {
     plugin->priv = g_new (FileRollerPluginPrivate, 1);
 
-    plugin->priv->default_ext = gnome_cmd_data_get_string (
-        "/file-runner-plugin/default_type", ".zip");
+    plugin->priv->default_ext = gnome_cmd_data_get_string ("/file-runner-plugin/default_type", ".zip");
 }
 
 
-
 /***********************************
  * Public functions
  ***********************************/
@@ -453,9 +454,7 @@ file_roller_plugin_get_type         (void)
 GnomeCmdPlugin *
 file_roller_plugin_new (void)
 {
-    FileRollerPlugin *plugin;
-
-    plugin = gtk_type_new (file_roller_plugin_get_type ());
+    FileRollerPlugin *plugin = gtk_type_new (file_roller_plugin_get_type ());
 
     return GNOME_CMD_PLUGIN (plugin);
 }
@@ -469,7 +468,8 @@ GnomeCmdPlugin *create_plugin (void)
 
 PluginInfo *get_plugin_info (void)
 {
-    if (!plugin_nfo.authors) {
+    if (!plugin_nfo.authors)
+    {
         plugin_nfo.authors = g_new (gchar*, 2);
         plugin_nfo.authors[0] = AUTHOR;
         plugin_nfo.authors[1] = NULL;
