@@ -14,11 +14,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_ADVRENAME_DIALOG_H__
 #define __GNOME_CMD_ADVRENAME_DIALOG_H__
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_ADVRENAME_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_advrename_dialog_get_type (), GnomeCmdAdvrenameDialog)
@@ -33,7 +35,6 @@ typedef struct _GnomeCmdAdvrenameDialogPrivate GnomeCmdAdvrenameDialogPrivate;
 typedef struct _GnomeCmdAdvrenameDialogClass GnomeCmdAdvrenameDialogClass;
 
 
-
 typedef struct
 {
     gchar *from;
@@ -57,6 +58,7 @@ struct _GnomeCmdAdvrenameDialogClass
 
 #define ADVRENAME_DIALOG_PAT_NUM_COLUMNS 3
 #define ADVRENAME_DIALOG_RES_NUM_COLUMNS 2
+
 extern guint advrename_dialog_default_pat_column_width[ADVRENAME_DIALOG_PAT_NUM_COLUMNS];
 extern guint advrename_dialog_default_res_column_width[ADVRENAME_DIALOG_RES_NUM_COLUMNS];
 
@@ -66,7 +68,6 @@ gnome_cmd_advrename_dialog_new (GList *files);
 GtkType
 gnome_cmd_advrename_dialog_get_type (void);
 
+G_END_DECLS
 
-
-
-#endif //__GNOME_CMD_ADVRENAME_DIALOG_H__
+#endif // __GNOME_CMD_ADVRENAME_DIALOG_H__
