@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GNOME_CMD_DATA_H__
@@ -30,6 +30,7 @@ typedef struct _GnomeCmdDataPrivate GnomeCmdDataPrivate;
 #include "filter.h"
 #include "history.h"
 
+G_BEGIN_DECLS
 
 struct _GnomeCmdData
 {
@@ -79,7 +80,6 @@ typedef struct {
 
 
 
-
 GnomeCmdData*
 gnome_cmd_data_new                       (void);
 
@@ -171,6 +171,9 @@ gnome_cmd_data_get_filter_settings      (void);
 gboolean
 gnome_cmd_data_get_type_filter          (GnomeVFSFileType type);
 
+void
+gnome_cmd_data_set_hidden_filter        (gboolean hide);
+
 gboolean
 gnome_cmd_data_get_hidden_filter        (void);
 
@@ -453,4 +456,18 @@ gnome_cmd_data_get_backup_pattern (void);
 GList *
 gnome_cmd_data_get_backup_pattern_list (void);
 
-#endif //__GNOME_CMD_DATA_H__
+GdkWindowState
+gnome_cmd_data_get_main_win_state (void);
+
+void
+gnome_cmd_data_set_main_win_state (GdkWindowState state);
+
+const gchar *
+gnome_cmd_data_get_symlink_prefix (void);
+
+void
+gnome_cmd_data_set_symlink_prefix (const gchar *value);
+
+G_END_DECLS
+
+#endif // __GNOME_CMD_DATA_H__
