@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __PLUGIN_MANAGER_H__
@@ -22,6 +22,8 @@
 
 #include <gmodule.h>
 
+G_BEGIN_DECLS
+
 typedef struct {
     gboolean active;
     gboolean loaded;
@@ -40,4 +42,6 @@ void plugin_manager_shutdown (void);
 GList *plugin_manager_get_all (void);
 void plugin_manager_show (void);
 
-#endif //__PLUGIN_MANAGER_H__
+G_END_DECLS
+
+#endif // __PLUGIN_MANAGER_H__
